@@ -51,7 +51,8 @@ public:
 
   void CalcSize();
 
-  void Draw(int x, int y, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 };
