@@ -23,7 +23,7 @@
 #include <Lum/Dlg/ActionDialog.h>
 
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 #include <Lum/Model/String.h>
 
 #include "Result.h"
